/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2014 Red Hat, Inc., and individual contributors
 * as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package io.undertow.http2.tests.framework;

import java.util.Collections;
import java.util.List;
import java.util.Map;

/**
 * A HTTP2 response
 *
 * @author Stuart Douglas
 */
public class HttpResponse {

    private final int status;
    private final Map<String, List<String>> headers;
    private final byte[] entityBody;

    public HttpResponse(int status, Map<String, List<String>> headers, byte[] entityBody) {
        this.status = status;
        this.headers = headers;
        this.entityBody = entityBody;
    }

    public int getStatus() {
        return status;
    }

    public Map<String, List<String>> getHeaders() {
        return Collections.unmodifiableMap(headers);
    }

    public byte[] getEntityBody() {
        return entityBody;
    }
}
